// SiN entity definition file for SinEd by Eutectic
// Version: 1.4
// Last modified: 20 June 99

// Change history

// V1.0
// Many corrections and additions from the original SINED declarations comments
// enbedded in Ritual's gameX86.dll V1.03 source code. The following versions
// will be corrections to this present version and won't use these comments as
// reference since those won't be updated by Ritual.
//
// Major overhaul to the entity descriptions, missing keys, keys that didn't work
// which were taken out, incomplete and/or innacurate key descriptions, same thing
// for the spawnflags and their descriptions. A few broken entities were removed
// or commented out (info_navbeacon, func_electrocute, func_shield). The missing
// 'skeetlauncher' entity was added.
//
// Plus way too many other changes to list here. Everything that was changed was
// thoroughly tested so just trust me, ok? :)
//
// The format and layout of the comments were also modified to make them more
// readable in SinEd's entity dialog window. Hope it makes your life easier.
// I'm open to suggestions and please, please, if you find errors, by all means,
// don't hesitate to email me and let me know (eutectic@ritualistic.com).
//
// V1.1
//
// - "angles" key and description added to func_camera.
// - "angle" key and description removed from func_securitycamera.
//
// V1.2
//
// - info_player_hardcorps and info_player_sintek for CTF added.
//
// V1.3
//
// - "angle" key added to func_scriptobject.
// - updated spline.def : definition of "loop" key for info_splinepath corrected.
// - updated rockturtop.def : typo correction in Notes plus additional info.
// - updated camgun2.def : typo correction in Notes.
// - definition of "height" key for func_camera and func_securitycamera corrected.
// - default value of "radius" key for lensflare corrected. Notes added.
// - definition of the "lightstyle" key for lensflare corrected.
// - "target" key and Notes added to waypoint.
// - func_beam beamstyles updated.
// - fixed problem with rockturtop.def displaying wrong model for trap_rocketturret.
// - added "sighttarget" and "sightthread" keys to trap_rocketturret (rockturtop.def).
// - added "sighttarget", "sightthread", "patience" and "lagtime" keys to
//   trap_securityturret (turtop.def).
// - added "noise" key for all trigger entities which also support message key.
// - improved definition of "message" key for triggers to be relevant to "noise" key.
//
// V1.4
//
// - added "noise" key to func_door, func_exploder, func_explodingwall,
//   func_multi_exploder, func_rotatingdoor, func_scriptdoor, inventory_genericpulsepart
//   and misc_oxygen since those also support the "message" key.
// - added a corrected version of batlow.def to the entity definition set: the entity is
//   already NOT_SOLID and NOT_DAMAGEABLE by default. The spawnflags were removed since
//   the default makes them useless.
// - added "scale" key and removed NOT_SOLID and NOT_DAMAGEABLE spawnflags (which make no
//   sense for pickup-able items) from inventory_genericpulsepart.
// - added corrected versions of all 25 inventory_* .def files in which all the relevant
//   keys were added and the NOT_SOLID and NOT_DAMAGEABLE spawnflags (which make no sense
//   for pickup-able items) were removed.
// - added corrected version of u4.def (Powerup_U4) with an accurate description (only a
//   static object) and the inclusion of the NOT_SOLID and NOT_DAMAGEABLE spawnflags & the
//   "targetname" key
// - added corrected versions of sledgeham.def (weapon_sledgehammer), stun.def (weapon_stun)
//   and wrench.def (weapon_wrench) with accurate descriptions (only static objects) and
//   the inclusion of the NOT_SOLID and NOT_DAMAGEABLE spawnflags for each & the "targetname"
//   key.
// - added corrected versions of cpu_keyboard_use.def (deskitems_cpu_keyboarduseable) and
//   cpu_monitor_use.def (deskitems_cpu_monitoruseable). Since these entities are already
//   not destructible by default, the NOT_DAMAGEABLE spawnflag was removed.
// - added corrected versions of sink.def (world_sink), toilet.def (world_toilet) and
//   urinal.def (world_urinal). Since these entities are sentients and not objects, the
//   NOT_SOLID and NOT_DAMAGEABLE spawnflags don't apply and were removed.
// - added corrected versions of all 17 gib_* .def files in which all the relevant keys
//   were added as well as the NOT_SOLID and NOT_DAMAGEABLE spawnflags.
// - added corrected versions of all 10 Projectile_* .def files in which all the relevant 
//   keys were added as well as the NOT_SOLID and NOT_DAMAGEABLE spawnflags.
// - added corrected versions of all 11 trap_* .def files in which many relevant keys
//   were added and incorrect ones were removed. The NOT_SOLID and NOT_DAMAGEABLE spawnflags
//   were added to claymore.def (trap_claymore), dynamite.def (trap_dynamite),
//   launcher_base.def (trap_missilelauncher_base), launcher.def (trap_oldlauncher),
//   rockturbase.def (trap_rocketturret_base) and turbase.def (trap_securityturret_base).
// - added corrected versions of all 19 vehicles_* .def files in which many relevant keys
//   were added and incorrect ones were removed. The NOT_SOLID and NOT_DAMAGEABLE spawnflags
//   were removed from atvtire_back.def (vehicles_atv_backtire), atvtire_front.def
//   (vehicles_atv_fronttire), humv_back_tire.def (vehicles_humv_backtire) and
//   humv_front_tire.def (vehicles_humv_fronttire). The NOT_DAMAGEABLE spawnflag was removed
//   from atv.def (vehicles_atv), bulldozer.def (vehicles_bulldozer), forklift.def
//   (vehicles_forklift), hcboat.def (vehicles_HCBoat), lamprey.def (vehicles_lamprey) and
//   lamprey_sintek.def (vehicles_lamprey_sintek).
// - added "surfacefile" key to worldspawn entity.
// - added corrected versions of all 16 fx_* .def files in which many relevant keys
//   were added and incorrect ones were removed. The NOT_SOLID and NOT_DAMAGEABLE spawnflags
//   were added to laser.def (fx_laser). The NOT_SOLID spawnflag was added to all the model
//   based fx_* entities : sphere.def, sphere2.def, sphere3.def (fx_explosion),
//   muzflash1.def (fx_muzzleflash), muzflash2.def (fx_muzzleflash2), beam.def
//   (fx_pulsebeam), beam2.def (fx_pulsebeam2), ln.def (fx_pulseline) and psphere.def
//   (fx_pulsesphere).
// - added "scale" and "targetname" keys to fx_fire.
// - removed "color" key and added "angle", "model" and "targetname" keys to fx_sprite
//   (fxsprite.def).
// - the START_OPEN spawnflag was removed from func_door, func_rotatingdoor and
//   func_scriptdoor since it doesn't work. The OPEN_DIRECTION spawnflag was removed from
//   func_rotatingdoor since it doesn't work.
// - the HURT_SHATTER spawnflag was removed from func_glass and func_shatter since it
//   doesn't work.
// - added the NOT_SOLID and NOT_DAMAGEABLE spawnflags to func_throwobject.
// - the NOT_PLAYERS spawnflag was removed from trigger_camerause since it doesn't work.


CONSOLE & DETAIL ENTITIES

-------------------------------------------------------------------------------

/*SINED console (0 .5 .8) ? NOUSE SCROLL MENU NOPVS
In-game consoles.
-------- KEYS --------
"consolename" : (required) con<consolename>. All console names must start with con.
"virtualwidth" : virtual width of the coordinate system (arbitrary units).
"virtualheight" : virtual height of the coordinate system (arbitrary units).
"fraction" : (0.0 - 1.0) This is the fraction of the console you want the scrolling part to take up on the screen (1 is 100%).
"scroll" : 0=off/1=on. Set to on if you want a scrolling console that takes user input (this is redundant with the scroll spawnflag).
"menu" : 0=off/1=on. Set to on if you want a user controlled menu (this is redundant with the menu spawnflag).
"rows" number of rows for scrolling console.
"cols" number of columns for scrolling console.
"menufile" name of file that contains the menu layout commands for this console.
"key" : item needed to use console (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"alpha" : sets the translucency of the entity (default 1.0).
-------- SPAWNFLAGS --------
NOUSE : set this if you don't want the user to be able to "use" the console.
SCROLL : shortcut for setting up the "scroll" mode.
MENU : shortcut for setting up the "menu" mode.
NOPVS : when sending console states over the net, don't use the PVS. (i.e. all state changes for this console alway get sent over). Warning! uses a lot of network bandwidth if you have multiple consoles that do this, it could overflow the network buffer.*/

-------------------------------------------------------------------------------

/*SINED detail (0.5 0 1.0) ?
Used to fake details brushes.*/

-------------------------------------------------------------------------------

FUNC_* ENTITIES

-------------------------------------------------------------------------------

/*SINED func_areaportal (0 0 0) ?
This is a non-visible variable size entity that divides the world into areas that are seperated when this portal is not activated. Must be enclosed in the middle of a door and should extend (height and width wise) into the door's surrounding frame (which must be made strictly from regular world brushes and not entities or detail brushes).
-------- KEYS --------
"targetname" : the door entity's target key points to this.
"target" :  each time areaportal is opened or closed, its targets will be triggered.*/

-------------------------------------------------------------------------------

/*SINED func_beam (0 .8 .5) (-8 -8 -8) (8 8 8) START_ON ANIMATE FAST ROLL RANDSTART ELECTRIC RANDALPHA 
This creates a beam effect which goes from its origin to the target's origin. Beams can use an info_notnul or a moving object (such as func_scriptobject) as an aiming target and will respond to script move* and rotate* type commands.
-------- KEYS --------
"color" : RGB color of the beam (default 1 1 1). Has no effect if model is set.
"alpha" : alpha of the beam (default 1.0).
"damage" : amount of damage to inflict when beam hits players, actors, monsters and destructible world models (default 0). When model is set, the beam can also damage a func_box.
"target" : point this to the targetname of the entity to use as aiming point (info_notnull or moving object). If the beam does not point to a target, it will aim at 0 degrees.
"diameter" : diameter of beam in map units (default 4). Has no effect if model is set.
"life" : amount of time in seconds before the beam is deactivated (default infinite). If this is set, beam won't inflict damage even if "damage" is set.
"beamstyle" : sets the style for this beam to cycle through.  This applies only to beams without models. Possible styles are:
    120 : gunsmoke
    121 : blood
    122 : sparks
    123 : orangeglow
    124 : blueyellow
    125 : debris trail
    126 : weird bubblegum
    127 : blood2
    128 : oil
    129 : waterspray
    130 : blue-yellow-blue
    131 : blue fade
"model" : specifies the model to use as the beam (.def file). Any model can be used for this but the ones more likely to produce good results are:
    beam.def
    beam2.def
    goo.def
    lightning.def
    ln.def
    muzflash1.def
    muzflash2.def
    pfxbegin.def
    pfxtile.def
"minoffset" : amount of electrical variation at the endpoint of beam (default 5).
"maxoffset" : amount of electrical variation in the middle of beam (default 25).
"overlap" : specifies the amount of overlap each beam link should have. Use this to fill in the cracks when using electric on beams or gaps in straight beams when small models are used (default 0).
"targetname" : the name refered to by trigger or script to control the beam. Triggering the beam will turn it on and it will remain on even if triggered again. If START_ON is set, triggering the beam will do nothing. Beams can be toggled on and off with the 'activate' and 'deactivate' commands.
-------- SPAWNFLAGS --------
START_ON : beam starts in the "on" state.
ANIMATE : plays animation of the model (model key must be set).
FAST : plays the model animation at 20 frames/sec (model key must be set).
ROLL : rolls the beam (model key must be set).
RANDSTART : starts each segment of the beam's animation on a different frame (model key must be set).
ELECTRIC : applies a random electric efffect to the beam (model key must be set).
RANDALPHA : randomly generate the alpha for the beam (model key must be set).
-------- NOTES --------
If the model key is not set, a straight beam will be created using the color specified. The minoffset, maxoffset and overlap keys plus the ANIMATE, FAST, ROLL, RANDSTART, ELECTRIC and RANDALPHA spawnflags are not applicable if the model key is not set.*/

-------------------------------------------------------------------------------

/*SINED func_box (0 .5 .8) ?
Explodable box that falls when boxes below it are destroyed. This can be made to spawn items, weapons, ammo, etc. and trigger its targets when destroyed.
-------- KEYS --------
"items" : list of items to spawn when the box is destroyed. Those must referred to by the name of the .def file that contains their entity definition and the names must be separated by spaces (Eg. "adren.def rlaunch.def" for Adrenaline and Rocket Launcher). Default is nothing.
"angles" : orientation of the box when it falls to the floor after another box below this one is destroyed. This also sets the angles of the item that is spawned. Will not work if the box is set to spawn more than one item (default 0 0 0).
"health" : amount of damage needed to destroy the box (default 60).
"target" : point to the entities to trigger when box is destroyed.
"alpha" : sets the translucency of the entity (default 1.0).*/

-------------------------------------------------------------------------------

/*SINED func_breakawaywall (0 .5 .8) ? x x NOT_PLAYERS MONSTERS PROJECTILES
Special walltype that removes itself when triggered. Will also trigger any func_areaportals that it targets.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"target" : point this to the func_areaportal within the wall.
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity (default 1.0). Warning: don't set this if the wall targets an areaportal.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, etc).*/

-------------------------------------------------------------------------------

/*SINED func_camera (1 0 0) ? ORBIT START_ON PAN
Camera used for cinematic sequences.
-------- KEYS --------
"angles" : pitch, yaw, roll direction in which camera will look when spawned (default 0 0 0).
"targetname" : name used by script to control the camera. A trigger_camerause can also point to this.
"target" : points to the target to orbit or follow.  If it points to a path, the camera will follow the path.
"distance" : the distance to follow or orbit if the target is not a path (default 128).
"speed" : specifies how fast to move on the path or orbit (default 1).
"fov" : specifies fov of camera (default 90).
"yaw" : specifies yaw of camera (default 0).
"height" : specifies height of camera from origin of entity while orbiting around it (default 128).
"panspeed" : speed at which to pan (default 7 deg/sec).
"panmax" : maximum angle offset for panning (default 45 deg).
"nextcamera" : point this to the next camera in a chain of cameras.
"overlay" : overlay file to use while looking through the camera.
"thread" : name of thread that will be called when the camera is looked through. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
ORBIT : tells the camera to create a circular path around the object it points to. If the camera points to a path, it will loop when it gets to the end of the path.
START_ON : causes the camera to be moving as soon as it is spawned.
PAN : camera should pan from right to left*/

-------------------------------------------------------------------------------

/*SINED func_clipbox (0 .5 .8) (-16 -16 -16) (16 16 16)
Invisible bounding box used like a clip brush. This is mainly used for blocking off areas or improving clipping without having to recompile the map. Because of this, it will most likely only be spawned via script.
-------- KEYS --------
"mins" : min point of the clip.
"maxs" : max point of the clip.
"type" : select from the following 3 options:
    0 : Monster and Player clip
    1 : Monster clip
    2 : Player clip*/

-------------------------------------------------------------------------------

/*SINED func_door (0 .5 .8) ? x x DOOR_DONT_LINK NOT_PLAYERS NOT_MONSTERS TOGGLE AUTO_OPEN TARGETED
Common sliding door. By default, doors must be used to open. Doors that touch are automatically teamed and operate as a single unit. Only doors of the same type that touch can be teamed.
-------- KEYS --------
"angle" : determines the opening direction (default 0).
"targetname" : if this is set, the door can be operated by an activating trigger or script commands but also retains its default use mode or proximity (if AUTO_OPEN is set) mode of operation.
"target" : point this to the func_areaportal within the door.
"time" : move time in seconds.
"speed" : move speed (100 default - overrides time).
"wait" : wait before returning (3 default, -1 = never return).
"lip" : lip remaining at end of move (8 default).
"dmg" : damage to inflict to player when he blocks the door (0 default).
"message" : text string to print on the screen every time the door is operated.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to open this door (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"sound_stop" : sound that plays when the door stops moving (default global door_stop).
"sound_move" : sound that plays when the door is moving (default global door_moving).
"sound_message" : sound that plays when the door displays a message.
"sound_locked" : sound that plays when the door is locked.
"alpha" : sets the translucency of the entity (default 1.0). Warning: don't set this if the door targets an areaportal.
-------- SPAWNFLAGS --------
DOOR_DONT_LINK : is for un-teaming doors that are touching (thus automatically teamed) so you can operate them independently.
NOT_PLAYERS : players cannot operate the door.
NOT_MONSTERS : monsters cannot operate the door.
TOGGLE : causes the door to wait in both the start and end states for a trigger event.
AUTO_OPEN : proximity mode, door will open when a player is near it instead of waiting for the player to use it.
TARGETED : use mode and proximity mode are disabled and door can only be operated by triggers or script commands ("targetname" must be set).
-------- NOTES --------
"health" key and START_OPEN spawnflag don't work and were removed.*/

-------------------------------------------------------------------------------

/*SINED func_earthquake (.5 .5 .8) (-8 -8 -8) (8 8 8)
Causes a localized earthquake when triggered.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"duration" : duration of the earthquake (0.8 seconds default).*/

-------------------------------------------------------------------------------

SINED func_electrocute (0 .5 .8) ?
Variable size. Electrocutes players when touched. Electrocutes everything it can see if it's in the water.
-------- KEYS --------
"radius" : range of the effect (default 500).
"key" : item needed to activate this (default nothing).
-------- NOTES --------
This entity doesn't work (confirmed by Aldie; commented out by Eutectic).

-------------------------------------------------------------------------------

/*SINED func_exploder (0.4 0 0) (0 0 0) (8 8 8) x x x BIG_EXPLOSION
Spawns an sprite based explosion effect when triggered. This can also trigger targets and call threads.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"dmg" : specifies how much damage to cause (default 120).
"scale" : specifies the scale of the explosion to make (default 1.0).
"volume" : volume at which to play explosion sound (default 1.0)
"attenuation" : attenuation for explosion sound (default normal)
"delay" : delay before explosion (default 0).
"wait" : amount of time before explosion, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"target" : point to the entities to trigger when explosion occurs.
"killtarget" : any entities this points to will be removed when explosion occurs.
"cnt" : how many times explosion can be triggered before removing itself (default: infinite).
"message" : text string to print on the screen every time the explosion is triggered.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
BIG_EXPLOSION : uses a bigger model based effect with smoke and particles instead.*/

-------------------------------------------------------------------------------

/*SINED func_explodingwall (0 .5 .8) ? RANDOMANGLES LANDSHATTER NOT_PLAYERS MONSTERS PROJECTILES INVISIBLE ACCUMULATIVE TWOSTAGE
Wall that falls down with an explosion effect when triggered or damaged. Can be made to fall in any position + angle and shatter after it falls. This can also trigger targets and call threads.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"health" : specifies how much damage to inflict before the wall explodes (default 60).
"explosions" : number of explosions to spawn (default 1).
"scale" : specifies the scale of the explosion to make (default 1.0).
"land_angles" : the angles you want this piece to orient to when it lands on the ground (default 0 0 0).
"land_radius" : the distance from the ground the piece should be when it lands on the ground (default 0).
"anglespeed" : speed at which pieces rotate while falling (default 100). If RANDOMANGLES is set, default is 600.
"target" : point to the entities to trigger when wall explodes.
"killtarget" : any entities this points to will be removed when wall explodes.
"message" : text string to print on the screen when wall explodes.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity (default 1.0).
-------- SPAWNFLAGS --------
RANDOMANGLES : object randomly spins while in the air.
LANDSHATTER : object shatters when it hits the ground (overrides TWOSTAGE).
NOT_PLAYERS : the activating trigger does not respond to players.
MONSTERS : the activating trigger will respond to monsters.
PROJECTILES : the activating trigger will respond to projectiles (rockets, grenades, etc).
ACCUMULATIVE : damage is accumulative instead of threshold based.
INVISIBLE : wall is invisible and not solid until triggered.
TWOSTAGE : wall can be shattered after it lands on the ground.*/

-------------------------------------------------------------------------------

/*SINED func_glass (0 .5 .8) ? x x NOT_PLAYERS NOT_MONSTERS NOT_PROJECTILES x THRESHOLD
For glass objects. Shatters when enough damage has been inflicted or when activated by trigger or script. This can also trigger targets and call threads.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"health" : specifies how much damage must occur before the glass shatters (default 20). The default noise is based on this value. If less or equal to 60, a small glass breaking sound is played. If more than 60, a large glass breaking sound is played.
"percentage" : specifies how much of the total volume of the brush to produce fragments from (default 50 percent).
"minsize" : minimum size of fragments, default based on brush size.
"maxsize" : maximum size of fragments, default based on brush size.
"thickness" : thickness of fragments, default based on brush size.
"noise" : sound to play when shattered (overrides default based on health).
"target" : point to the entities to trigger when glass shatters.
"killtarget" : any entities this points to will be removed when glass shatters.
"message" : text string to print on the screen when glass shatters.
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity (default 1.0).
-------- SPAWNFLAGS --------
NOT_PLAYERS : activating trigger does not respond to events caused by players.
NOT_MONSTERS : activating trigger does not respond to events caused by monsters.
NOT_PROJECTILES : activating trigger does not respond to events caused by projectiles.
THRESHOLD : damage is threshold based instead of accumulative.
-------- NOTES --------
HURT_SHATTER spawnflag doesn't work and was removed.*/

-------------------------------------------------------------------------------

/*SINED func_group (0 0 0) ?
Not an entity. Merely an editor convenience used to group brushes together.*/

-------------------------------------------------------------------------------

/*SINED func_illusionary (0 .5 .8) ?
Entity's brush will be visible but not solid and lets you walk through it. If "targetname" is set, this can be removed during the game by having a trigger's "killtarget" key point to it or by using the 'remove' script command.
-------- KEYS --------
"targetname" : name used by trigger or script to remove this.
"alpha" : sets the translucency of the entity (default 1.0).*/

-------------------------------------------------------------------------------

/*SINED func_launcher (0 1 0) ? 
Variable size entity that launches projectiles when triggered. Using "shotrocket" as projectile type will make this launch guided rockets that veer and seek the player.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"target" : point this to an info_notnull entity to use as aiming point.
"projectile" : sets the projectile type to launch. Possible types are:
    spear
    mine
    rocket
    shotrocket (guided rocket)
    drunkmissile
"launchsound" : sets the launching sound. This is independent from the projectile which makes its own sound.
"alpha" : sets the translucency of the entity (default 1.0).*/

-------------------------------------------------------------------------------

/*SINED func_multi_exploder (0.4 0 0) ? x RANDOM_TIME RANDOM_SCALE BIG_EXPLOSION
Spawns multiple sprite based explosion effects when triggered and then removes itself. The explosions are confined to the volume occupied by the brush so the position and size of brush determine where and how close to one another the explosions occur. This can trigger targets and call threads.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"dmg" : specifies how much damage to cause from each explosion (default 120).
"scale" specifies the scale of the explosions to make (default 1.0).
"volume" : volume at which to play explosion sound (default 0.5).
"attenuation" : attenuation for explosion sound (default normal).
"delay" : delay before beginning of explosions (default 0).
"wait" : time between each explosion (default 0.25).
"duration" : how long to explode for (default 1).
"random" : random factor (default 0.25).
"target" : point to the entities to trigger when explosion occurs.
"killtarget" : any entities this points to will be removed when explosions occurs.
"message" : text string to print on the screen when the explosions are triggered.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
RANDOM_TIME : adjusts the wait between each explosion by the random factor.
RANDOM_SCALE : adjusts the size of each explosion by the random factor.
BIG_EXPLOSION : uses a bigger model based effect with smoke and particles instead.*/  

-------------------------------------------------------------------------------

/*SINED func_remove (0 0.5 0) ?
Used for area lighting. Brush will remove itself from the world when map starts, only the light emitted by its faces will remain.*/

-------------------------------------------------------------------------------

/*SINED func_respawn(0 .5 .8) (-8 -8 -8) (8 8 8) 
This will spawn a model when triggered. When the thing that is spawned is killed, the func_respawn will get re-triggered and spawn the model again. It can spawn any model but it's mainly used for spawning monsters.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"angle" : direction model will be facing when spawned.
"modelname" : name of the .def file you wish to spawn (required).
"attackmode" : attacking mode of the spawned monster. Possible modes are:
    0: normal mode - will go for player and use duck and cover pathnodes (default).
    1: stand ground - won't move from its spawn spot (except melee monsters).
    2: blitzkrieg - will go for player but won't use duck and cover pathnodes.
-------- NOTES --------
"key" and "spawntargetname" keys don't work: removed.*/

-------------------------------------------------------------------------------

/*SINED func_rotatingdoor (0 .5 .8) ? x x DOOR_DONT_LINK NOT_PLAYERS NOT_MONSTERS TOGGLE AUTO_OPEN TARGETED
Rotating door. By default, doors must be used to open. Doors that touch are automatically teamed and operate as a single unit. Only doors of the same type that touch can be teamed.
-------- KEYS --------
"angle" : determines the opening direction. Point toward the middle of the door (away from the hinge).
"openangle" : the angle the door will rotate when operated. Positive values make the door open away from the player and negative values make the door open toward the player (default 90 degrees).
"origin" : optional alternative to the use of an origin brush as the center of rotation of the entity. Set this to the XYZ coordinate you want the entity to use as it's center of rotation.
"targetname" : if this is set, the door can be operated by an activating trigger or script commands but also retains its normal proximity (AUTO_OPEN) or use (default) mode of operation.
"target" : point this to the func_areaportal within the door.
"time" : move time (0.3 default).
"wait" : wait before returning (3 default, -1 = never return).
"dmg" : damage to inflict to player when he blocks the door (0 default).
"message" : text string to print on the screen every time the door is operated.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to open this door (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"sound_stop" : sound that plays when the door stops moving (default global door_stop).
"sound_move" : sound that plays when the door is moving (default global door_moving).
"sound_message" : sound that plays when the door displays a message.
"sound_locked" : sound that plays when the door is locked.
"alpha" : sets the translucency of the entity (default 1.0). Warning: don't set this if the door targets an areaportal.
-------- SPAWNFLAGS --------
DOOR_DONT_LINK : is for un-teaming doors that are touching (thus automatically teamed) so you can operate them independently.
NOT_PLAYERS : players cannot operate the door.
NOT_MONSTERS : monsters cannot operate the door.
TOGGLE : causes the door to wait in both the start and end states for a trigger event.
AUTO_OPEN : proximity mode, door will open when a player is near it instead of waiting for the player to use it.
TARGETED : use mode and proximity mode are disabled and door can only be operated by triggers or script commands ("targetname" must be set).
-------- NOTES --------
"health", "speed" keys removed and START_OPEN, OPEN_DIRECTION spawnflags don't work and were removed.*/

-------------------------------------------------------------------------------

/*SINED func_scriptdoor (0 .5 .8) ? x x DOOR_DONT_LINK NOT_PLAYERS NOT_MONSTERS TOGGLE AUTO_OPEN TARGETED
Script door. Opening and closing movement/rotation must be done with script threads. By default, doors must be used to open. Doors that touch are automatically teamed and operate as a single unit. Only doors of the same type that touch can be teamed.
-------- KEYS --------
"angle" : determines the opening direction. Point toward the middle of the door (away from the hinge).
"origin" : optional alternative to the use of an origin brush as the center of rotation of the entity. Set this to the XYZ coordinate you want the entity to use as it's center of rotation.
"targetname" : if this is set, the door can be operated by an activating trigger or script commands but also retains its default use mode or proximity (if AUTO_OPEN is set) mode of operation.
"target" : point this to the func_areaportal within the door.
"time" : move time in seconds.
"wait" : wait before returning (3 default, -1 = never return).
"dmg" : damage to inflict to player when he blocks the door (0 default).
"message" : text string to print on the screen every time the door is operated.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to open this door (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"initthread" : thread to execute to setup the door (optional).
"openthread" : thread to execute when opening the door (required).
"closethread" : thread to execute when closing the door (required).
"sound_stop" : sound that plays when the door stops moving (default global door_stop).
"sound_move" : sound that plays when the door is moving (default global door_moving).
"sound_message" : sound that plays when the door displays a message.
"sound_locked" : sound that plays when the door is locked.
"alpha" : sets the translucency of the entity (default 1.0). Warning: don't set this if the door targets an areaportal.
-------- SPAWNFLAGS --------
DOOR_DONT_LINK : is for un-teaming doors that are touching (thus automatically teamed) so you can operate them independently.
NOT_PLAYERS : players cannot operate the door.
NOT_MONSTERS : monsters cannot operate the door.
TOGGLE : causes the door to wait in both the start and end states for a trigger event.
AUTO_OPEN : proximity mode, door will open when a player is near it instead of waiting for the player to use it.
TARGETED : use mode and proximity mode are disabled and door can only be operated by triggers or script commands ("targetname" must be set).
-------- NOTES --------
"health", "speed" keys removed and START_OPEN spawnflag doesn't work and was removed.*/

-------------------------------------------------------------------------------

/*SINED func_scriptmodel (0 .5 .8) (0 0 0) (0 0 0) NOT_SOLID
This will spawn a script slave model completely dependent on script commands for its behavior.
-------- KEYS --------
"targetname" : name used by script to control model.
"model" : name of .def file to use for model (required).
"anim" : name of initial animation frame sequence of model (.sam file).
"scale" : scale of model (default set by .def file).
"angle" : orientation of model (default 0).
"angles" : pitch, yaw and roll orientation of model (overrides angle - default 0 0 0).
"skin" : name of skin to use for model (when applicable).
"key" : item needed to use model (default nothing). This is useful if you have a script thread in which there is an 'onuse' event monitoring command for this model. This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"alpha" : sets the translucency of the entity (default 1.0).
-------- SPAWNFLAGS --------
NOT_SOLID : model will be visible but not solid.*/

-------------------------------------------------------------------------------

/*SINED func_scriptobject (0 .5 .8) ? NOT_SOLID
Script slave entity. Object made from one or several brushes completely dependent on script commands for its movement and rotation. Use for any type of moving mechanism other than doors.
-------- KEYS --------
"angle" : this sets the reference pointing angle for the moveForward, moveBackward, moveLeft and moveRight script commands.
"targetname" : name used by script to control object.
"origin" : optional alternative to the use of an origin brush as the center of rotation of the entity. Set this to the XYZ coordinate you want the entity to use as it's center of rotation.
"key" : item needed to use object (default nothing). This is useful if you have a script thread in which there is an 'onuse' event monitoring command for this object. This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"alpha" : sets the translucency of the entity (default 1.0).
-------- SPAWNFLAGS --------
NOT_SOLID : object will be visible but not solid.*/

-------------------------------------------------------------------------------

/*SINED func_scriptorigin (0 .5 .8) (-4 -4 -4) (4 4 4)
Used as an alternate origin for objects. Bind the object to the func_scriptorigin in the script in order to simulate changing that object's origin.
-------- KEYS --------
"targetname" : name used by script for binding and control.*/

-------------------------------------------------------------------------------

/*SINED func_shatter (0 .5 .8) ? x x NOT_PLAYERS NOT_MONSTERS NOT_PROJECTILES x THRESHOLD
For shattering objects other than glass. Shatters when enough damage has been inflicted or when activated by a trigger or script. This can trigger a targeted func_areaportal when not invisible and can also trigger regular targets and call threads.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"health" : specifies how much damage must occur before object shatters (default 20).
"percentage" : specifies how much of the total volume of the brush to produce fragments from (default 50 percent).
"minsize" : minimum size of fragments, default based on brush size.
"maxsize" : maximum size of fragments, default based on brush size.
"thickness" : thickness of fragments, default based on brush size.
"noise" : sound to play when shattered (default none).
"target" : point this to an areaportal or to the entities to trigger when object shatters.
"killtarget" : any entities this points to will be removed when object shatters.
"message" : text string to print on the screen when object shatters.
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity (default 1.0). Warning: don't set this if the object targets an areaportal.
-------- SPAWNFLAGS --------
NOT_PLAYERS : activating trigger does not respond to events caused by players.
NOT_MONSTERS : activating trigger does not respond to events caused by monsters.
NOT_PROJECTILES : activating trigger does not respond to events caused by projectiles.
THRESHOLD : damage is threshold based instead of accumulative.
-------- NOTES --------
HURT_SHATTER spawnflag doesn't work and was removed.*/

-------------------------------------------------------------------------------

SINED func_shield (0 0 .5) ?
This doesn't seem to work but tests are inconclusive.
-------- KEYS --------
"health" : health of the shield (default 100).
"hitalpha" : translucency of the shield when hit or touched.
"clearalpha" : translucency of the shield when not hit or touched.
-------- NOTES --------
This entity does nothing else but what the HURT_SHATTER spawnflag should normally do for the func_glass and func_shatter entity (if it worked): release fragments when hit until it shatters. No Alpha change here - Commented out by Eutectic.


-------------------------------------------------------------------------------

/*SINED func_spawn(0 .5 .8) (-8 -8 -8) (8 8 8)
This will spawn a model when triggered. It can spawn any model but it's mainly used for spawning monsters.
-------- KEYS --------
"targetname" : the activating trigger or script points to this name. 
"angle" : direction model will be facing when spawned.
"modelname" : name of the .def file you wish to spawn (required).
"spawntargetname" : this will be the targetname of the spawned model (default is null).
"attackmode" : attacking mode of the spawned monster. Possible modes are:
    0: normal mode - will go for player and use duck and cover pathnodes (default).
    1: stand ground - won't move from its spawn spot (except melee monsters).
    2: blitzkrieg - will go for player but won't use duck and cover pathnodes.
-------- NOTES --------
"key" key doesn't work: removed.*/

-------------------------------------------------------------------------------

/*SINED func_spawnchain(0 .5 .8) (-8 -8 -8) (8 8 8) 
This will try to spawn a model when triggered but will succeed only if there is no direct line of sight between itself and any players. If it fails, it will trigger its targets.
-------- KEYS --------
"targetname" : the activating trigger or script points to this name. 
"angle" : direction model will be facing when spawned.
"modelname" : name of the .def file you wish to spawn (required).
"spawntargetname" : this will be the targetname of the spawned model (default is null).
"target" : point this to the entity to trigger.
-------- NOTES --------
"key" key doesn't work: removed.*/

-------------------------------------------------------------------------------

/*SINED func_spawnoutofsight(0 .5 .8) (-8 -8 -8) (8 8 8) 
This will try to spawn a model when triggered but will succeed only if there is no direct line of sight between itself and any players.
-------- KEYS --------
"targetname" : the activating trigger or script points to this name. 
"angle" : direction model will be facing when spawned.
"modelname" : name of the .def file you wish to spawn (required).
"spawntargetname" : this will be the targetname of the spawned model (default is null).
-------- NOTES --------
"key" & "target" keys don't work: removed. The description for this was wrong.*/

-------------------------------------------------------------------------------

/*SINED func_throwobject (0 .5 .8) (0 0 0) (0 0 0) NOT_SOLID NOT_DAMAGEABLE
This is a model actors can pickup and throw at players or other actors.
-------- KEYS --------
"targetname" : the script refers to this name.
"model" : name of .def file to use for model (required).
"anim" : name of initial animation frame sequence of model (.sam file).
"scale" : scale of model (default set by .def file).
"angle" : orientation of model (default 0).
"angles" : pitch, yaw and roll orientation of model (default 0 0 0).
"skin" : name of skin to use for model (when applicable).
"alpha" : sets the translucency of the entity (default 1.0).
-------- NOTES --------
This responds to the script commands: pickup, throw, pickupoffset, throwsound.*/

-------------------------------------------------------------------------------

/*SINED func_volumetric (0 .5 .8) ?
Use this to make non-solid volumes for fog effects, wide sunbeams and light beams, etc. Set up the brush's surface properties with the "add-blend" flag. Will respond to bind, move and rotate script commands the same as func_scriptobject's.
-------- KEYS --------
"targetname" : the script refers to this name.
"origin" : optional alternative to the use of an origin brush as the center of rotation of the entity. Set this to the XYZ coordinate you want the entity to use as it's center of rotation.
*/

-------------------------------------------------------------------------------

/*SINED func_wall (0 .5 .8) ?
This is just a solid wall. If "targetname" is set, this can be removed during the game by having a trigger's "killtarget" key point to it or by using the 'remove' script command.
-------- KEYS --------
"targetname" : name used by trigger or script to remove this.
"alpha" : sets the translucency of the entity (default 1.0).*/

-------------------------------------------------------------------------------

FX_* ENTITIES

-------------------------------------------------------------------------------

/*SINED fx_fire (0 .8 .5) (-8 -8 -8) (8 8 8) SINGLE STAR PARALLEL
This creates a fire sprite, it defaults to 2 sprites in a cross shape. If you want the flame to make a flickering effect on the surrounding walls, you can set the style key to the 'group' name of the surfaces to control.
-------- KEYS --------
"scale" : scale of sprite in game (bounding box won't be adjusted in SinEd).
"style" : set this to brush faces 'group' name in surface inspector (default 0).
"on_style" light style to set to when "on" (default is a flicker).
"off_style" light style to set to when "off" (default is "a").
"alpha" : sets the translucency of the sprite (default 1.0).
"targetname" : name referred to when controlled by a script.
-------- SPAWNFLAGS --------
SINGLE : only one oriented sprite.
STAR : 4 sprites in a star shape.
PARALLEL : sprite will always face player as he moves around it.*/

-------------------------------------------------------------------------------

INFO_* ENTITIES

-------------------------------------------------------------------------------

/*SINED info_grav_pathnode (0 0 .5) (-16 -16 0) (16 16 32) HEADNODE FORCE
Gravity pathnode: attracts players who walk within its set radius. You can daisy-chain these in a path and the first node in the path must have the HEADNODE spawnflag set. The players can be attracted to any node in the path depending on which is closest to them. Activating or deactivating the head node with script commands (activate, deactivate) will activate or deactivate all the nodes in the path.
-------- KEYS --------
"targetname" : name of this node, the previous node in path points to this.
"target" : points to the next node in the path.
"radius" : radius of the pull effect (default 256).
"speed" : speed of the pull, use negative value for a repulsion (default 100).
-------- SPAWNFLAGS --------
HEADNODE : signifies this node is the head of the path.
FORCE : makes gravity un-fightable (player can't go backwards).
-------- NOTES --------
To activate or deactivate the gravity path, use the activate & deactivate script commands on the HEADNODE pathnode.*/

-------------------------------------------------------------------------------

SINED info_monster_spawnspot (1 0 0) (-16 -16 0) (16 16 64)
Potential spawn location for a monster.
-------- KEYS --------
"spawngroup" : the name of the group of spawn spots that this one belongs to. Monsters use spawngroup to choose which spawn spots to spawn at.
"angle" : the orientation for the monster to spawn in.
"angles" : the full (x,y,z) orientation for the monster to spawn in (default 0 0 0).
"anim" : the animation that the monster should use when spawning here.
-------- NOTES --------
This entity doesn't seem to do anything - Commented out by Eutectic.

-------------------------------------------------------------------------------

/*SINED info_notnull (0 0.5 0) (-4 -4 -4) (4 4 4)
Used as a positional target for func_beam, func_launcher and trigger_pushany.
-------- KEYS --------
"targetname" : proper entity points to this.*/

-------------------------------------------------------------------------------

/*SINED info_null (0 0.5 0) (-4 -4 -4) (4 4 4)
Used as a positional target for lights (spotlight effect).
-------- KEYS --------
"targetname" : light entity points to this.*/

-------------------------------------------------------------------------------

/*SINED info_pathnode (1 0 0) (-24 -24 0) (24 24 32) FLEE DUCK COVER DOOR JUMP LADDER ACTION
Path location nodes used for actor control in scripts. They are used mainly to make them move around from one place to another and do stuff using script commands.
-------- KEYS --------
"angle" : direction the actor will look when reaching this node.
"target" : the name of the next node the actor will walk or run to. If JUMP is set, the actor will jump to the next node.
"targetname" : the name of the previous node that points to this. Also the name used in a script to refer to this node.
"anim" : name of actor .sam animation to play when actor reaches this node. The animation will loop once then the actor will revert to his default animation.
-------- SPAWNFLAGS --------
FLEE : marks the node as a safe place to flee to. Actor will be removed when it reaches a flee node and is not visible to a player.
DUCK : marks the node as a good place to duck behind during weapon fire.
COVER : marks the node as a good place to hide behind during weapon fire.
DOOR : marks the node as a door node. If an adjacent node has DOOR marked as well, the actor will only use the path if the door in between them is unlocked.
JUMP : marks the node as one to jump from when going to the node specified by target.
LADDER : marks the node as a ladder node.
ACTION : marks the node as an action node.*/

-------------------------------------------------------------------------------

/*SINED info_player_coop (1 0 1) (-16 -16 0) (16 16 64)
Potential spawning position for coop games.
-------- KEYS --------
"angle" : direction in which the player is facing when spawned.
"gravityaxis" : sets the gravity axis in which the player will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.*/

-------------------------------------------------------------------------------

/*SINED info_player_deathmatch (1 0 1) (-16 -16 0) (16 16 64)
Potential spawning position for deathmatch games.
-------- KEYS --------
"angle" : direction in which the player is facing when spawned.
"gravityaxis" : sets the gravity axis in which the player will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.*/

-------------------------------------------------------------------------------

/*SINED info_player_intermission (1 0 1) (-16 -16 0) (16 16 64)
Camera-like viewpoint used in between deathmatch levels.
-------- KEYS --------
"angles" : pitch, yaw, roll orientation of viewpoint (default 0 0 0).*/

-------------------------------------------------------------------------------

/*SINED info_player_start (1 0 0) (-16 -16 0) (16 16 64)
The normal starting point for a level. There is normally one per level in a single player map. If you have more than one, you must assign a targetname to all of them. You can thus have several starting points at which the player can spawn when coming from a previous map. For more info, see trigger_changelevel.
-------- KEYS --------
"angle" : direction in which the player is facing when spawned.
"targetname" : must be used if there is more than one of these in a map.
"gravityaxis" : sets the gravity axis in which the player will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.*/

-------------------------------------------------------------------------------

CTF TEAM PLAYER START ENTITIES

-------------------------------------------------------------------------------

/*SINED info_player_hardcorps (1 0 1) (-16 -16 0) (16 16 64)
Hardcorps team start position for Capture The Flag games.
-------- KEYS --------
"angle" : direction in which the player is facing when spawned.
"gravityaxis" : sets the gravity axis in which the player will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.*/

-------------------------------------------------------------------------------

/*SINED info_player_sintek (1 0 1) (-16 -16 0) (16 16 64)
SinTek team start position for Capture The Flag games.
-------- KEYS --------
"angle" : direction in which the player is facing when spawned.
"gravityaxis" : sets the gravity axis in which the player will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.*/

-------------------------------------------------------------------------------

INVENTORY_* ENTITIES

-------------------------------------------------------------------------------

/*SINED inventory_genericpulsepart (.3 1 .3) (-8 -8 0) (8 8 16)
Pulse Weapon Part - Place only one per level. This will automatically spawn as the next piece that the player needs to complete the weapon depending of which one(s) he already has. Once the player has picked up 3 of these, he will get the PulseRifle.
-------- KEYS --------
"angle" : direction in which the part is facing when spawned.
"angles" : alternate pitch, yaw, roll orientation method for part (overrides angle -  default 0 0 0).
"scale" : controls size of model in the game (ex: 1.0).
"target" : the entity this points to will be triggered when item is picked up.
"killtarget" : the entity this points to will be removed when item is picked up.
"message" : text string to print on screen when item is picked up (default: none).
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to be able to pick this up (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : don't use this (duh!)
"thread" : name of thread to call when item is picked up. This can be in a different script file as well by using the '::' notation.
"gravityaxis" : sets the gravity axis in which the item will spawn. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.
"alpha" : translucency of model in game. Values are from 0-1 (default: 1).*/

-------------------------------------------------------------------------------

LIGHT ENTITIES

-------------------------------------------------------------------------------

/*SINED lensflare (0 1 0) (-8 -8 -8) (8 8 8)
Lensflare effect sprite.
-------- KEYS --------
"color" : RGB color of lensflare, 3 values between 0 and 1 (default 1 1 1).
"light" : if set, will make the flare emit a dynamic light (default is not set).
"radius" : radius of the dynamic light (default is not set).
"scale" : scale of the lensflare (default 0.5).
"sprite" : sprite model to use for the flare (default sprites/glow.spr).
"lightstyle" : makes the lensflare sprite blink, pulse or flicker by following a preset light style (defined in global/global0.scr). Does not affect the light emitted by the lensflare (default is not set). Style choices are:
    0 : normal
    1 : flicker (first variety)
    2 : slow strong pulse
    3 : candle (first variety)
    4 : fast strobe
    5 : gentle pulse 1
    6 : flicker (second variety)
    7 : candle (second variety)
    8 : candle (third variety)
    9 : slow strobe (fourth variety)
   10 : fluorescent flicker
   11 : slow pulse not fade to black
-------- NOTES --------
"light" and "radius" must both be set for the lensflare to emit a dynamic light. Setting the "lightstyle" key will automatically reset the lensflare color to white.*/

-------------------------------------------------------------------------------

/*SINED light (0 1 0) (-8 -8 -8) (8 8 8) START_OFF
Non-displayed light source.
-------- KEYS --------
"light" : light intensity value (default 300).
"_color" : RGB color of light (default 1 1 1).
"_cone" : sets size of light cone for spotlights (default 10).
"style" : gives the light a preset light style (defined in global/global0.scr). Has no effect on targeted lights (use "on_style" and "off_style" for those). Style choices are:
    0 : normal (default)
    1 : flicker (first variety)
    2 : slow strong pulse
    3 : candle (first variety)
    4 : fast strobe
    5 : gentle pulse 1
    6 : flicker (second variety)
    7 : candle (second variety)
    8 : candle (third variety)
    9 : slow strobe (fourth variety)
   10 : fluorescent flicker
   11 : slow pulse not fade to black
"on_style" : light style to set to when "on" (default is "m").
"off_style" : light style to set to when "off" (default is "a").
"targetname" : if targeted, will toggle between on and off when triggered.
"target" : point this to an info_null entity to make a spotlight effect. The distance between the light and the info_null affect the size and intensity of the light cone. This can also target a triggerable entity which will be used both as an aiming point for the light and be activated when the light is itself triggered.
"key" : item needed to toggle light when targeted (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
-------- SPAWNFLAGS --------
START_OFF : light will spawn in the "off" state.
-------- NOTES --------
Can't get "on_style" and "off_style" to work ..."and I don't know why Capteen!"*/

-------------------------------------------------------------------------------

/*SINED light_ramp (0 .5 .8) (-8 -8 -8) (8 8 8) TOGGLE
Non-displayed light source that ramps its intensity from one level to another when triggered. By default, it will ramp from "startlevel" to "endlevel" only once and remain at that level even if triggered again (unless TOGGLE is set).
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"time" : how many seconds the ramping will take (default 1.0).
"startlevel" : value between 0 and 2.0 (default 1.0).
"endlevel" : value between 0 and 2.0 (default 0).
"light" : maximum light intensity value on which level 2.0 is based (default 300).
"_color" : RGB color of light (default 1 1 1).
"_cone" : sets size of light cone for spotlights (default 10).
"target" : point this to an info_null entity to make a spotlight effect. The distance between the light and the info_null affect the size and intensity of the light cone. This can also target a triggerable entity which will be used both as an aiming point for the light and be activated when the light is itself triggered.
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
-------- SPAWNFLAGS --------
TOGGLE : light source will alternately ramp up and ramp down each time it's triggered.*/

-------------------------------------------------------------------------------

MISC_* ENTITIES

-------------------------------------------------------------------------------

/*SINED misc_medkit (1.0 0.2 0.2) ?
Variable size entity both visible and solid in the game. This heals players to their max health when used.
-------- KEYS --------
"alpha" : sets the translucency of the entity (default 1.0).*/

-------------------------------------------------------------------------------

/*SINED misc_oxygen (1 0 0) ? VISIBLE
Variable size entity. This will reset the drowning time when touched - only responds to players.
-------- KEYS --------
"target" : the entities this points to will be triggered when entity is touched.
"killtarget" : any entities this points to will be removed when the entity is touched.
"message" : text string to print on the screen every time the entity is touched.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default none).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when this is touched. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
-------- SPAWNFLAGS --------
VISIBLE : the entity brush will be visible in the game.*/

-------------------------------------------------------------------------------

/*SINED misc_teleporter (1 0 0) ? VISIBLE x NOT_PLAYERS NOT_MONSTERS NOT_PROJECTILES
Touching this entity will teleport players to the targeted misc_teleporter_destination.
-------- KEYS --------
"target" : point this to the misc_teleporter_destination where the players will be teleported.
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"gravityaxis" : sets player's axis of gravity when teleported. Possible values are:
    0 : down is towards the negative side of the Z axis (default normal gravity).
    1 : down is towards the negative side of the X axis.
    2 : down is towards the negative side of the Y axis.
    3 : down is towards the positive side of the Z axis (inverse normal gravity).
    4 : down is towards the positive side of the X axis.
    5 : down is towards the positive side of the Y axis.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
-------- SPAWNFLAGS --------
VISIBLE : this makes the teleporter brush visible.
NOT_PLAYERS : the teleporter does not teleport players.
NOT_MONSTERS : the teleporter does not teleport monsters.
NOT_PROJECTILES : the teleporter does not teleport projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED misc_teleporter_dest (1 0 0) (-32 -32 0) (32 32 8)
Teleporter destination location. Point a misc_teleporter at this.
-------- KEYS --------
"angle" : direction in which the player will be facing when teleported.
"targetname" : the misc_teleporter from where the players are teleported points to this.*/

-------------------------------------------------------------------------------

SKEETLAUNCHER ENTITY

-------------------------------------------------------------------------------

/*SINED skeetlauncher (0 .5 .8) ?
Variable size entity. This is the skeetlauncher used in the Hardcorps Training Center. It launches clay pigeons the player can shoot. Completely script controlled.
-------- KEYS --------
"targetname" : name used by script to control entity.
"alpha" : sets the translucency of the entity (default 1.0).
-------- NOTES --------
The script commands which apply to this entity are: launch, setDuration, setGravity, setSpeed, setSpeedVar, setXdir, setYdir, setZdir, setXvar, setYvar and setZvar.*/

-------------------------------------------------------------------------------

TRIGGER_* ENTITIES

-------------------------------------------------------------------------------

/*SINED trigger_camerause (0.5 0.5 0.5) ? VISIBLE x x MONSTERS
Variable size trigger. Activates the targeted camera's view when used. Once used, pressing the use key again will cycle through camera views in round-robin fashion.
-------- KEYS --------
"target" : point this to a func_camera or func_securitycamera entity.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
VISIBLE : trigger brush will be both visible and solid.
NOT_PLAYERS : trigger will not respond to players.
MONSTERS : trigger will respond to monsters.
-------- NOTES --------
"key" key removed and NOT_PLAYERS spawnflag doesn't work so it was removed.*/

-------------------------------------------------------------------------------

/*SINED trigger_changelevel (0.5 0.5 0.5) ? NO_INTERMISSION x NOT_PLAYERS MONSTERS PROJECTILES
Variable size trigger. When the player touches this, he gets sent to the map listed in the "map" key. In deathmatch, the view will go to the info_intermission spot (if one exists) and display stats.
-------- KEYS --------
"map" : name of next .bsp file (no extension) to load. To clear all save game data from previous levels, precede the name of the map with a '*' character. If you want the player to start in a specific location in the next map, follow the map name with the targetname of the info_player_start entity located where you want him to start. For example, if the name of the map is "mymap.bsp" and the targetname of the info_player_start is "spot1", set the "map" key to "*mymap$spot1".
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : this defaults to "LevelComplete" and should point to a thread that is called just before the level ends.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NO_INTERMISSION: don't show the info_intermission view.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_damagetargets (0.5 0.5 0.5) ? SOLID x NOT_PLAYERS NOT_MONSTERS PROJECTILES
Variable size trigger that will inflict damage to its targets when activated by another trigger and/or shot at if SOLID is set (cannot be touch activated). When transferring damage to the targets by hurting the trigger, none of the other keys (damage, cnt, message, key, thread) are active.
-------- KEYS --------
"target" : this points to the entities to inflict damage to.
"targetname" : the activating trigger points to this.
"damage" : amount of damage to inflict. If no damage is specified, targeted objects are damaged by their current health +1 (IOW destroyed).
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
SOLID : trigger will be solid and damage its targets by the same amount inflicted to it.
NOT_PLAYERS : trigger does not hurt players
NOT_MONSTERS : trigger does not hurt monsters
PROJECTILES : trigger will hurt projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_damagetargetsfixed (0.5 0.5 0.5) (-8 -8 -8) (8 8 8) SOLID x NOT_PLAYERS NOT_MONSTERS PROJECTILES
This is the same as trigger_damagetargets except it's a fixed size version. Since no brush can be tied to it, it can't transfer damage to its targets because it can't be hurt (even if SOLID is set). Must be activated by another trigger.
-------- KEYS --------
"target" : this points to the entities to inflict damage to.
"targetname" : the activating trigger points to this.
"damage" : amount of damage to inflict. If no damage is specified, targeted objects are damaged by their current health +1 (IOW destroyed).
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
SOLID : serves no other purpose than to make trigger solid. Useless.
NOT_PLAYERS : trigger does not hurt players
NOT_MONSTERS : trigger does not hurt monsters
PROJECTILES : trigger will hurt projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_damagethreshold (0 .5 .8) ? x INVISIBLE NOT_PLAYERS MONSTERS ACCUMULATIVE
Variable size solid trigger that fires its targets only when a threshold of damage inflicted to it is exceeded. If this targets func_breakawaywall entities for example, it lets you create a set of walls that can only be destroyed by a weapon that delivers enough one-shot damage to activate the trigger. Will also trigger any targeted func_areaportals when not invisible.
-------- KEYS --------
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : minimum amount of one-shot damage to inflict for the trigger to activate its targets (default 60).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : specifies how many times the trigger can fire before it will remove itself (default 1, -1 is infinite firing).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity if INVISIBLE is NOT set (default 1.0).
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
INVISIBLE : trigger will still be solid but not visible.
NOT_PLAYERS : trigger does not respond to damage caused by players.
MONSTERS : trigger will respond to damage caused by monsters.
ACCUMULATIVE : damage to inflict is cumulative instead of threshold based.*/

-------------------------------------------------------------------------------

/*SINED trigger_exit (0.5 0.5 0.5) ?
Variable size trigger. When the player touches this, an exit icon will be displayed on his hud. This is to inform him that he is near an exit.
-------- KEYS --------
"targetname" : name refered to when controlled by script.*/

-------------------------------------------------------------------------------

/*SINED trigger_hurt (0.5 0.5 0.5) ? x x NOT_PLAYERS NOT_MONSTERS PROJECTILES
Variable size trigger thats will inflict damage when touched.
-------- KEYS --------
"damage" : amount of damage to cause (default 10).
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : specifies how many times the trigger can fire before it will remove itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not hurt players.
NOT_MONSTERS : trigger does not hurt monsters.
PROJECTILES : trigger will hurt projectiles (mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_lightramp (0 1 0) (-8 -8 -8) (8 8 8) TOGGLE
Ramps light values on surface based light sources from one level to another when triggered. By default, it will ramp from "startlevel" to "endlevel" once when triggered and remain at that level even if triggered again (unless TOGGLE is set). The brush faces controlled by this must have the 'light' surface flag and a 'direct value' set in surf inspector.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"style" : set this to brush faces 'group' name in surface inspector (default 0).
"time" : how many seconds the ramping will take (default 1.0).
"startlevel" : value between 0 and 2.0 (default 1.0).
"endlevel" : value between 0 and 2.0 (default 0).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
-------- SPAWNFLAGS --------
TOGGLE : surface light will alternately ramp up and ramp down each time it's triggered.*/

-------------------------------------------------------------------------------

/*SINED trigger_multiple (.5 .5 .5) ? x x NOT_PLAYERS MONSTERS PROJECTILES
Variable size repeatable trigger that fires its targets when touched or killed. Can also call a script thread.
-------- KEYS --------
"target" : this points to the entities to trigger when activated.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : if this is set, trigger must be killed instead of touched to be activated (this also makes trigger solid).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_mutate (0.5 0.5 0.5) ? VISIBLE x NOT_PLAYERS NOT_MONSTERS
Variable size trigger that will transform players into a mutant when touched or killed. Common trigger keys also work. Monsters can activate trigger but are not transformed into mutants.
-------- KEYS --------
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : if this is set, trigger must be killed instead of touched to be activated (this also makes trigger solid).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
VISIBLE : trigger brush will be both visible and solid.
NOT_PLAYERS : players can't activate trigger.
NOT_MONSTERS : monsters can't activate trigger .*/

-------------------------------------------------------------------------------

/*SINED trigger_once (.5 .5 .5) ? NOTOUCH x NOT_PLAYERS MONSTERS PROJECTILES
Variable size trigger that fires its targets when touched or killed. Can also call a script thread. Triggers once, then removes itself.
-------- KEYS --------
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : if this is set, trigger must be killed instead of touched to be activated (this also makes trigger solid).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"message" : text string to print on the screen when the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOTOUCH : this makes the trigger non-solid when "health" is set.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_particles (0.3 0.1 0.6) (-8 -8 -8) (8 8 8)  x NOSOUND NOT_PLAYERS MONSTERS PROJECTILES RANDSTYLE BRIGHT 
This will spawn particles when triggered.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"count" : number of particles to spawn each time this is triggered (default 10).
"noise" : sound to play when triggered (defaults to random spark sounds).
"angles": pitch, yaw, roll direction in which to spawn particles (default 0 0 0).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"particlestyle" : style of particles (default 122 - sparks). Sample styles are:
120 : gunsmoke
121 : blood
123 : orangeglow
124 : blueyellow
125 : debris trail
128 : oil
129 : waterspray
-------- SPAWNFLAGS --------
NOSOUND : no sound will be played.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).
RANDSTYLE : particles will be set to random colors in the particlestyle.
BRIGHT : particles will be drawn extra bright.*/

-------------------------------------------------------------------------------

/*SINED trigger_push (.5 .5 .5) ? x x NOT_PLAYERS NOT_MONSTERS NOT_PROJECTILES
Variable size trigger. Pushes players, monsters, actors and projectiles as if they were caught in a heavy wind when touched.
-------- KEYS --------
"speed" : speed at which the entities are pushed (default 1000).
"angle" : direction in which the entities are pushed (-1 is up, -2 is down, default -1).
"target" : this will trigger the entity it points to (if triggerable) and use it as an aiming point (overrides "angle"). Setting this also has an effect on the resulting speed and angle of push which is then based on a combination of the value of the "speed" key, the position of the targeted entity (overrides "angle") plus the angle of approach and speed of collision of the player with the trigger: the faster the player walks into the trigger brush, the stronger the push.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not push players.
NOT_MONSTERS : trigger will not push monsters.
NOT_PROJECTILES : trigger will not push projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_pushany (.5 .5 .5) ? x x NOT_PLAYERS NOT_MONSTERS NOT_PROJECTILES
Same thing as a trigger_push but will push entities in any direction set by "angles".
-------- KEYS --------
"speed" : speed at which the entities are pushed (default 1000).
"angles": pitch, yaw, roll direction in which to push entities (default 0 0 0).
"target" : this will trigger the entity it points to (if triggerable) and use it as an aiming point (overrides "angles"). Setting this also has an effect on the resulting speed and angle of push which is then based on a combination of the value of the "speed" key, the position of the targeted entity plus the angle of approach and speed of collision of the player with the trigger: the faster the player walks into the trigger brush, the stronger the push.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when activated. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not push players.
NOT_MONSTERS : trigger will not push monsters.
NOT_PROJECTILES : trigger will not push projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_randomparticles (0.3 0.1 0.6) (-8 -8 -8) (8 8 8) START_ON NOSOUND NOT_PLAYERS MONSTERS PROJECTILES RANDSTYLE BRIGHT 
This will spawn particles at random time intervals when triggered.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"count" : number of particles to spawn each time this is triggered (default 10).
"noise" : sound to play when triggered (defaults to random spark sounds).
"angles": pitch, yaw, roll direction in which to spawn particles (default 0 0 0).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"particlestyle" : style of particles (default 122 - sparks). Sample styles are:
120 : gunsmoke
121 : blood
123 : orangeglow
124 : blueyellow
125 : debris trail
128 : oil
129 : waterspray
"mindelay" : minimum delay between particle triggers (default 3).
"maxdelay" : maximum delay between particle triggers (default 10).
-------- SPAWNFLAGS --------
START_ON : particle effect will initially be on and turn off when triggered.
NOSOUND : no sound will be played.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).
RANDSTYLE : particles will be set to random colors in the particlestyle.
BRIGHT : particles will be drawn extra bright.*/

-------------------------------------------------------------------------------

/*SINED trigger_randomspeaker (0.3 0.1 0.6) (-8 -8 -8) (8 8 8) x RELIABLE NOT_PLAYERS MONSTERS PROJECTILES x x
This will play a sound at random time intervals when triggered. Don't use this with ambient looping sounds.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"volume" : loudness 0-4 (default 1).
"noise" : sound (.wav file) to play.
"channel" : channel on which to play sound
    0 : auto
    1 : weapon
    2 : voice (default)
    3 : item
    4 : body
    5 : dialog
    6 : secondary dialog
    7 : weaponidle
    8 : don't use PHS
"pitch" : pitch of the sound (default 1, normal pitch).
"fadetime" : fade the sound over a time period in seconds (default 0, no fade).
"timeofs" : start time offset of sound in milli-seconds (default 0, no timeofs).
"attenuation" : attenuation factor
   -1 : none, send to whole level
    0 : default (normal or ambient)
    1 : normal fighting sounds
    2 : idle monster sounds
    3 : static (same as ambient sounds)
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"mindelay" : minimum delay between sounds (default 3).
"maxdelay" : maximum delay between sounds (default 10).
-------- SPAWNFLAGS --------
RELIABLE : should only be set for crucial voice-overs or sounds.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_relay (.5 .5 .5) (-8 -8 -8) (8 8 8) x x NOT_PLAYERS MONSTERS PROJECTILES
This fixed size trigger cannot be touched, it can only be activated by other triggers and act as an intermediary to trigger other entities.
-------- KEYS --------
"targetname" : the activating trigger points to this.
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen when the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when triggered. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not respond to events triggered by players.
MONSTERS : trigger will respond to events triggered by monsters.
PROJECTILES : trigger will respond to events triggered by projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_secret (.5 .5 .5) ? NOTOUCH x NOT_PLAYERS MONSTERS PROJECTILES
Variable size secret counter trigger. Automatically sets and increments the script variables level.total_secrets and level.found_secrets. Triggers once, then removes itself. Make one for each secret in your map.
-------- KEYS --------
"target" : this points to the entities to trigger.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : if this is set, trigger must be killed instead of touched to be activated (this also makes trigger solid).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"message" : text string to print on the screen when the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when triggered. This can be in a different script file as well by using the '::' notation (defaults to "global/universal_script.scr::secret").
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOTOUCH : this makes the trigger non-solid when "health" is set.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_SetLightStyle (0 1 0) (-8 -8 -8) (8 8 8) START_OFF
Used for controlling surface based light sources. The brush faces controlled by this must have the 'light' surface flag and a 'radiosity' or 'direct value' set in surf inspector.
-------- KEYS --------
"targetname" : name used by trigger or script to activate this. Will toggle between on and off states each time it's triggered.
"style" : set this to the brush faces 'group' name in surface inspector (default 0).
"on_style" : light style to set to when "on" (default is "m").
"off_style" : light style to set to when "off" (default is "a").
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
-------- SPAWNFLAGS --------
START_OFF : surface light will start in the "off" state.*/

-------------------------------------------------------------------------------

/*SINED trigger_speaker (0.3 0.1 0.6) (-8 -8 -8) (8 8 8) AMBIENT_ON RELIABLE NOT_PLAYERS MONSTERS PROJECTILES AMBIENT_OFF x TOGGLE
This will play a sound when triggered. Normal sounds play once each time the trigger is activated. Ambient looped sounds have an attenuation 2 + volume 1 and start off by default. Multiple identical ambient looping sounds will just increase volume without any speed cost. If neither AMBIENT_ON or AMBIENT_OFF are set, the sound is sent over explicitly throughout the level (this creates more net traffic).
-------- KEYS --------
"targetname" : name used by trigger or script to activate this.
"volume" : loudness 0-4 (default 1). Ambient sounds do not respond to volume.
"noise" : sound (.wav file) to play.
"channel" : channel on which to play sound
    0 : auto
    1 : weapon
    2 : voice (default)
    3 : item
    4 : body
    5 : dialog
    6 : secondary dialog
    7 : weaponidle
    8 : don't use PHS
"pitch" : pitch of the sound (default 1, normal pitch).
"fadetime" : fade the sound over a time period in seconds (default 0, no fade).
"timeofs" : start time offset of sound in milli-seconds (default 0, no timeofs).
"attenuation" : attenuation factor (0 becomes 1 for non-ambients, 2 for ambients).
   -1 : none, send to whole level
    0 : default (normal or ambient)
    1 : normal fighting sounds
    2 : idle monster sounds
    3 : ambient sounds
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when triggered. This can be in a different script file as well by using the '::' notation.
-------- SPAWNFLAGS --------
AMBIENT_ON : ambient sounds start on and toggle on/off each time the speaker is triggered.
RELIABLE : should only be set for crucial voice-overs or sounds.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).
AMBIENT_OFF : ambient sounds start off and toggle on/off each time the speaker is triggered (default).
TOGGLE : ambient sounds toggle on/off each time the speaker is triggered.*/

-------------------------------------------------------------------------------

/*SINED trigger_thread (.5 .5 .5) ? x x NOT_PLAYERS MONSTERS PROJECTILES
Variable size trigger. This will call a script thread when touched or killed. Can also trigger its targets.
-------- KEYS --------
"target" : this points to the entities to trigger when activated.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"health" : if this is set, trigger must be killed instead of touched to be activated (this also makes trigger solid).
"delay" : amount of time trigger waits after being activated before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to more than 1.
"cnt" : how many times trigger can be activated before removing itself (default 1).
"message" : text string to print on the screen when the trigger is activated. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call. This can be in a different script file as well by using the '::' notation.
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.
PROJECTILES : trigger will respond to projectiles (rockets, grenades, mines).*/

-------------------------------------------------------------------------------

/*SINED trigger_use (0.5 0.5 0.5) ? VISIBLE x NOT_PLAYERS MONSTERS
Variable size trigger that fires its targets when 'used' by a player. This can also call a script thread.
-------- KEYS --------
"target" : this points to the entities to trigger when used.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being used before firing its targets (default 0).
"wait" : amount of time before trigger, once activated, responds to activation again (.2 default). This is useful only if "cnt" is set to a value other than 1.
"cnt" : how many times trigger can be activated before removing itself (default: infinite).
"message" : text string to print on the screen every time the trigger is used. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when used. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
VISIBLE : trigger brush will be both visible and solid.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.*/

-------------------------------------------------------------------------------

/*SINED trigger_useonce (0.5 0.5 0.5) ? VISIBLE x NOT_PLAYERS MONSTERS
Variable size trigger that fires its targets when 'used' by a player. This can also call a script thread. Triggers once, then removes itself.
-------- KEYS --------
"target" : this points to the entities to trigger when used.
"killtarget" : any entities this points to will be removed when the trigger is fired.
"delay" : amount of time trigger waits after being used before firing its targets (default 0).
"message" : text string to print on the screen when the trigger is used. Setting this also allows "noise" sound to be played when message is printed.
"noise" : sound to play when "message" is printed. The "message" key must be set for sound to be heard (default environment/switch/switch2.wav).
"key" : item needed to activate this (default nothing). This can be any Inventory_* type entity. Use the last part of the entity name (after "Inventory_"). The only exceptions are:
    ChemBioSuit : use chemsuit instead
    cookies : works but doesn't generate an icon
    genericpulsepart : works but doesn't generate an icon
"thread" : name of thread to call when used. This can be in a different script file as well by using the '::' notation.
"alpha" : sets the translucency of the entity if VISIBLE is set (default 1.0).
"targetname" : name refered to when controlled by script.
-------- SPAWNFLAGS --------
VISIBLE : trigger brush will be both visible and solid.
NOT_PLAYERS : trigger does not respond to players.
MONSTERS : trigger will respond to monsters.*/

-------------------------------------------------------------------------------

WAYPOINT & WORLDSPAWN ENTITIES

-------------------------------------------------------------------------------

/*SINED waypoint (0 0.5 0) (-8 -8 -8) (8 8 8)
Used as a positioning location for scriptobjects and scriptmodels. Refer to this by its targetname when moving objects with script commands. These can also be daisy-chained to one another target-targetname wise.
-------- KEYS --------
"targetname" : name used by script to refer to this location. The previous waypoint in a chain can also point to this.
"target" : this points to the next waypoint in the chain.
-------- NOTES --------
When waypoints are daisy-chained, the script command 'next' can be used to move objects from one to the other. The object must be moved to a waypoint first. Then, the next waypoint is the one that the current waypoint targets.*/

-------------------------------------------------------------------------------

/*SINED worldspawn (0 0 0) ? CINEMATIC
Only used for the world: all the world brushes are automatically part of this entity. This is automatically created in a new map and SinEd does not let you insert it since only one worldspawn entity per level is allowed. Select any world brush before setting the keys for this.
-------- KEYS --------
"surfacefile" : name of surface file used in SinEd.
"sky" : environment map name in the base/env folder. This must be set to the first letters common to the names of all 6 TGA files which make up the environment map (default sky_).
"skyaxis" : rotation axis toggle for rotating sky. Set one or several of the 3 possible axes of rotation - X Y Z. For example, if you want the sky to rotate along the X and Z axes, set this to "1 0 1" (default 0 0 0).
"skyrotate" : speed of rotation of sky in degrees/second. The sky will rotate along each of the axes set in "skyaxis" at the specified speed. If this is set, make sure at least one of the axes of rotation is set in "skyaxis" otherwise the sky will produce a Hall-Of-Mirrors effect (default 0).
"cdtrack" : music CD track number. The Sin CD has no audio tracks but if a music CD is present in your drive while you play the map, the track number will be played (default 0).
"soundtrack" : name of .mus music configuration file to use for map. Music files are in the base/music folder and the file extension must be omitted (default none).
"gravity" : gravity of the level. Lower values produce lower gravity (default 800 - normal).
"message" : text to print on game console at user logon. This will be the map's title name used in the savegame and loadgame menus (default is the map's filename) and the mission console.
"skipthread" : thread that is called to skip this level if it's defined as a cinematic level (CINEMATIC spawnflag set or 'cinematic' command in script). When the player hits either the use, jump or fire key during the cinematic, the thread will be called.
"script" : name of script file to use for this map. If set, the file name and extension must be specified. If not set, the map will try to load a script by the same name as the map filename with an .scr extension by default.
"watercolor" : specifies the player's view blend color while in water (default 0 0 1).
"wateralpha" : specifies the translucency of the player's view blend while in water. Values are from 0 to 1 - 0 is 100% clear, 1 is 100% opaque (default 0.1).
"lavacolor" : specifies the player's view blend color while in lava (default 1.0 0.3 0).
"lavaalpha" : specifies the translucency of the player's view blend while in lava. Values are from 0 to 1 - 0 is 100% clear, 1 is 100% opaque (default 0.6).
"lightcolor" : specifies the player's view blend color while in slime (default 1 1 1).
"lightalpha" : specifies the translucency of the player's view blend while in slime. Values are from 0 to 1 - 0 is 100% clear, 1 is 100% opaque (default 0.5).
-------- SPAWNFLAGS --------
CINEMATIC : sets the map as a cinematic level.*/

-------------------------------------------------------------------------------